import json

def getTranslations():
    translations = {}
    with open('bible-translations.json', 'r') as file:
        translations = json.loads(file.read())

    return translations

def parse(version_to_parse):
    version_to_parse = version_to_parse.lower()
    versions = getTranslations()

    data = {}
    for version in versions:
        if version['name'].lower() == version_to_parse or version['abbr'].lower() == version_to_parse:
            data = version

        else:
            for alias in version['aliases']:
                if alias.lower() == version_to_parse:
                    data = version

    return data

def getAll(field, value):
    versions = getTranslations()

    data = []
    for version in versions:
        try:
            if version[field].lower() == value.lower():
                data.append(version)

        except KeyError: # some translations don't have certain information, thus raising a KeyError
            continue

    return data



from setuptools import setup


with open("README.md", "r") as file:
    long_description = file.read()

setup(
    name="bver",
    py_modules=["bver"],
    version="v0.1.1",
    description="A simple Bible translation parser for human input",
    author="MotS",
    author_email="ted.jameson@pm.me",
    url="https://code.theres.life/heb12/bver",
    keywords=["bible", "json", "parser"]
)
